@@ -67,9 +67,13 @@ fitModelCpp <- function(type,
 
   mcmc.list <- list()
 
+
+
   simBetaMPT <- function(idx){
 
-    sim <- betampt(M = n.iter, H = as.matrix(data),
+    sim <- betampt(M = ceiling(n.iter/n.thin),
+                   nthin = n.thin,
+                   H = as.matrix(data),
                    a = mpt.res$a, b = mpt.res$b,
                    c = mpt.res$c, map = mpt.res$map,
                    shape = shape, rate = rate )
@@ -80,18 +84,20 @@ fitModelCpp <- function(type,
       colnames(sim$bet) <- paste0("bet[",1:S,"]")
     }
     tnames <- outer(1:S,paste0(",",1:N), paste0)
-    tt <- matrix(sim$theta, nrow = n.iter, ncol=S*N,
+    tt <- matrix(sim$theta, nrow = ceiling(n.iter/n.thin), ncol=S*N,
                  dimnames=list(NULL, paste0("theta[",c(t(tnames)),"]")))
     tmp <- with(sim, cbind(mean, sd, alph, bet, tt ))
     if(S == 1)
       colnames(tmp)[1:4] <- c("mean","sd","alph","bet")
     # mcmc(tmp, start = n.burnin+1, end=n.iter, thin = n.thin)
-    window(mcmc(tmp), start = n.burnin+1, thin = n.thin)
+    window(mcmc(tmp), start = floor(n.burnin/n.thin) + 1, thin = 1L)
   }
 
   simSimpleMPT <- function(idx){
 
-    sim <- simplempt(M = n.iter, H = as.matrix(data),
+    sim <- simplempt(M = ceiling(n.iter/n.thin),
+                     nthin = n.thin,
+                     H = as.matrix(data),
                      a = mpt.res$a, b = mpt.res$b,
                      c = mpt.res$c, map = mpt.res$map,
                      alpha = alpha, beta = beta )
@@ -106,12 +112,12 @@ fitModelCpp <- function(type,
     }
 
     tnames <- outer(1:S,paste0(",",1:N), paste0)
-    tt <- matrix(sim$theta, nrow = n.iter, ncol=S*N,
+    tt <- matrix(sim$theta, nrow = ceiling(n.iter/n.thin), ncol = S*N,
                  dimnames=list(NULL, paste0("theta[",c(t(tnames)),"]")))
     tmp <- with(sim, cbind(means, sds, tt ))
 
     # mcmc(tmp, start = n.burnin+1, end=n.iter, thin = n.thin)
-    window(mcmc(tmp), start = n.burnin+1, thin = n.thin)
+    window(mcmc(tmp), start = floor(n.burnin/n.thin)+1, thin = 1L)
   }
 
 
